# Slot: mixins


List of definitions to be mixed in. Targets may be any definition of the same type

URI: [http://w3id.org/biolink/biolinkml/meta/mixins](slot_uri)
## Domain and Range

[Definition](Definition.md) -><sub>opt</sub> [[Definition](Definition.md)]
## Inheritance

## Children

 *  [class definition.mixins](class_definition_mixins.md)
 *  [slot definition.mixins](slot_definition_mixins.md)
## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [SlotDefinition](SlotDefinition.md)
